@@ -1,6 +1,6 @@
 /*************************************************************************
  *
- * Copyright (c) 2012-2016 Kohei Yoshida
+ * Copyright (c) 2012-2018 Kohei Yoshida
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
@@ -102,6 +102,17 @@ public:
         size_type column;
         size_pair_type() : row(0), column(0) {}
         size_pair_type(size_type _row, size_type _column) : row(_row), column(_column) {}
+        size_pair_type(std::initializer_list<size_type> vs)
+        {
+            if (vs.size() != 2)
+                throw invalid_arg_error("size_pair_type requires exactly 2 elements.");
+
+            size_type* ptrs[2] = { &row, &column };
+            size_type** p = ptrs;
+
+            for (size_type v : vs)
+                **p++ = v;
+        }
 
         bool operator== (const size_pair_type& r) const { return row == r.row && column == r.column; }
         bool operator!= (const size_pair_type& r) const { return !operator== (r); }
@@ -149,7 +160,7 @@ public:
 
 private:
     template<typename _Func>
-    struct walk_func : std::unary_function<typename store_type::const_iterator::value_type, void>
+    struct walk_func
     {
         _Func& m_func;
         walk_func(_Func& func) : m_func(func) {}
@@ -710,9 +721,11 @@ public:
      *
      * @param func function object whose operator() gets called on each
      *             element block.
+     *
+     * @return function object passed to this method.
      */
     template<typename _Func>
-    void walk(_Func& func) const;
+    _Func walk(_Func func) const;
 
     /**
      * Walk through the element blocks in a sub-matrix range defined by start
@@ -727,9 +740,11 @@ public:
      * @param end the column/row position of the lower-right corner of the
      *          sub-matrix.  Both column and row must be greater or equal to
      *          those of the start position.
+     *
+     * @return function object passed to this method.
      */
     template<typename _Func>
-    void walk(_Func& func, const size_pair_type& start, const size_pair_type& end) const;
+    _Func walk(_Func func, const size_pair_type& start, const size_pair_type& end) const;
 
     /**
      * Walk through all element blocks in parallel with another matrix
@@ -742,7 +757,7 @@ public:
      * @param right another matrix instance to parallel-walk with.
      */
     template<typename _Func>
-    void walk(_Func& func, const multi_type_matrix& right) const;
+    _Func walk(_Func func, const multi_type_matrix& right) const;
 
     /**
      * Walk through the element blocks in a sub-matrix range in parallel with
@@ -763,7 +778,7 @@ public:
      *          those of the start position.
      */
     template<typename _Func>
-    void walk(_Func& func, const multi_type_matrix& right,
+    _Func walk(_Func func, const multi_type_matrix& right,
         const size_pair_type& start, const size_pair_type& end) const;
 
 
