@@ -1,6 +1,6 @@
 /*************************************************************************
  *
- * Copyright (c) 2012-2016 Kohei Yoshida
+ * Copyright (c) 2012-2018 Kohei Yoshida
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
@@ -28,7 +28,6 @@
 #ifndef MDDS_MULTI_TYPE_VECTOR_TYPES_HPP
 #define MDDS_MULTI_TYPE_VECTOR_TYPES_HPP
 
-#include "default_deleter.hpp"
 #include "global.hpp"
 
 #include <algorithm>
@@ -91,7 +90,6 @@ struct base_element_block
 protected:
     element_t type;
     base_element_block(element_t _t) : type(_t) {}
-    ~base_element_block() {}
 };
 
 template<typename _Self, element_t _TypeId, typename _Data>
@@ -151,6 +149,11 @@ public:
         return get(block).m_array.at(pos);
     }
 
+    static value_type* data(base_element_block& block)
+    {
+        return get(block).m_array.data();
+    }
+
     static typename store_type::size_type size(const base_element_block& block)
     {
         return get(block).m_array.size();
@@ -176,6 +179,16 @@ public:
         return get(block).m_array.end();
     }
 
+    static const_iterator cbegin(const base_element_block& block)
+    {
+        return get(block).m_array.begin();
+    }
+
+    static const_iterator cend(const base_element_block& block)
+    {
+        return get(block).m_array.end();
+    }
+
     static reverse_iterator rbegin(base_element_block& block)
     {
         return get(block).m_array.rbegin();
@@ -196,6 +209,16 @@ public:
         return get(block).m_array.rend();
     }
 
+    static const_reverse_iterator crbegin(const base_element_block& block)
+    {
+        return get(block).m_array.rbegin();
+    }
+
+    static const_reverse_iterator crend(const base_element_block& block)
+    {
+        return get(block).m_array.rend();
+    }
+
     static _Self& get(base_element_block& block)
     {
 #ifdef MDDS_MULTI_TYPE_VECTOR_DEBUG
@@ -547,7 +570,7 @@ struct managed_element_block : public copyable_element_block<managed_element_blo
 
     ~managed_element_block()
     {
-        std::for_each(m_array.begin(), m_array.end(), mdds::default_deleter<_Data>());
+        std::for_each(m_array.begin(), m_array.end(), std::default_delete<_Data>());
     }
 
     static self_type* create_block_with_value(size_t init_size, _Data* val)
@@ -574,7 +597,7 @@ struct managed_element_block : public copyable_element_block<managed_element_blo
         managed_element_block& blk = get(block);
         typename managed_element_block::store_type::iterator it = blk.m_array.begin() + pos;
         typename managed_element_block::store_type::iterator it_end = it + len;
-        std::for_each(it, it_end, mdds::default_deleter<_Data>());
+        std::for_each(it, it_end, std::default_delete<_Data>());
     }
 };
 
@@ -596,7 +619,7 @@ struct noncopyable_managed_element_block : public noncopyable_element_block<nonc
 
     ~noncopyable_managed_element_block()
     {
-        std::for_each(m_array.begin(), m_array.end(), mdds::default_deleter<_Data>());
+        std::for_each(m_array.begin(), m_array.end(), std::default_delete<_Data>());
     }
 
     static self_type* create_block_with_value(size_t init_size, _Data* val)
@@ -623,7 +646,7 @@ struct noncopyable_managed_element_block : public noncopyable_element_block<nonc
         noncopyable_managed_element_block& blk = get(block);
         typename noncopyable_managed_element_block::store_type::iterator it = blk.m_array.begin() + pos;
         typename noncopyable_managed_element_block::store_type::iterator it_end = it + len;
-        std::for_each(it, it_end, mdds::default_deleter<_Data>());
+        std::for_each(it, it_end, std::default_delete<_Data>());
     }
 };
 
