@@ -1,6 +1,6 @@
 /*************************************************************************
  *
- * Copyright (c) 2010 Kohei Yoshida
+ * Copyright (c) 2010-2015 Kohei Yoshida
  * 
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
@@ -25,8 +25,8 @@
  *
  ************************************************************************/
 
-#ifndef __MDDS_POINT_QUAD_TREE_HPP__
-#define __MDDS_POINT_QUAD_TREE_HPP__
+#ifndef INCLUDED_MDDS_POINT_QUAD_TREE_HPP
+#define INCLUDED_MDDS_POINT_QUAD_TREE_HPP
 
 #include "mdds/quad_node.hpp"
 
@@ -36,8 +36,7 @@
 #include <fstream>
 #include <string>
 #include <vector>
-
-#include <boost/shared_ptr.hpp>
+#include <memory>
 
 #define DEBUG_POINT_QUAD_TREE 0
 
@@ -104,7 +103,7 @@ void search_region_node(
 }
 
 
-template<typename _Key, typename _Data>
+template<typename _Key, typename _Value>
 class point_quad_tree
 {
 private:
@@ -112,9 +111,9 @@ private:
 
 public:
     typedef _Key    key_type;
-    typedef _Data   data_type;
+    typedef _Value  value_type;
     typedef size_t  size_type;
-    typedef ::std::vector<data_type> data_array_type;
+    typedef ::std::vector<value_type> data_array_type;
 
     class data_not_found : public ::std::exception {};
 
@@ -124,8 +123,8 @@ private:
 
     struct node : quad_node_base<node_ptr, node, key_type>
     {
-        data_type data;
-        node(key_type _x, key_type _y, data_type _data) :
+        value_type data;
+        node(key_type _x, key_type _y, value_type _data) :
             quad_node_base<node_ptr, node, key_type>(_x, _y),
             data(_data) {}
 
@@ -159,18 +158,18 @@ public:
      */
     class node_access
     {
-        friend class point_quad_tree<_Key,_Data>;
+        friend class point_quad_tree<_Key,_Value>;
     public:
         node_access northeast() const { return node_access(mp->northeast.get()); }
         node_access northwest() const { return node_access(mp->northwest.get()); }
         node_access southeast() const { return node_access(mp->southeast.get()); }
         node_access southwest() const { return node_access(mp->southwest.get()); }
 
-        data_type data() const { return mp->data; }
+        value_type data() const { return mp->data; }
         key_type x() const { return mp->x; }
         key_type y() const { return mp->y; }
 
-        operator bool() const { return mp != NULL; }
+        operator bool() const { return mp != nullptr; }
         bool operator== (const node_access& r) const { return mp == r.mp; }
 
         node_access& operator= (const node_access& r)
@@ -179,7 +178,7 @@ public:
             return *this;
         }
 
-        node_access() : mp(NULL) {}
+        node_access() : mp(nullptr) {}
         node_access(const node_access& r) : mp(r.mp) {}
         ~node_access() {}
 
@@ -198,23 +197,23 @@ public:
         point() : x(0), y(0) {}
     };
 
-    class search_result
+    class search_results
     {
         friend class search_result_inserter;
 
-        typedef ::std::vector<const node*>          res_nodes_type;
-        typedef ::boost::shared_ptr<res_nodes_type> res_nodes_ptr;
+        typedef std::vector<const node*>        res_nodes_type;
+        typedef std::shared_ptr<res_nodes_type> res_nodes_ptr;
     public:
 
         class const_iterator
         {
-            friend class point_quad_tree<_Key,_Data>::search_result;
-            typedef typename point_quad_tree<_Key,_Data>::point point;
-            typedef typename point_quad_tree<_Key,_Data>::data_type data_type;
+            friend class point_quad_tree<_Key,_Value>::search_results;
+            typedef typename point_quad_tree<_Key,_Value>::point point;
+            typedef typename point_quad_tree<_Key,_Value>::value_type parent_value_type;
 
         public:
             // Iterator traits
-            typedef ::std::pair<point, data_type> value_type;
+            typedef std::pair<point, parent_value_type> value_type;
             typedef value_type*     pointer;
             typedef value_type&     reference;
             typedef ptrdiff_t       difference_type;
@@ -258,17 +257,17 @@ public:
                 return !operator==(r);
             }
 
-            const ::std::pair<point, data_type>& operator*() const
+            const value_type& operator*() const
             {
                 return m_cur_value;
             }
 
-            const ::std::pair<point, data_type>* operator->() const
+            const value_type* operator->() const
             {
                 return get_current_value();
             }
 
-            const ::std::pair<point, data_type>* operator++()
+            const value_type* operator++()
             {
                 // The only difference between the last data position and the 
                 // end iterator position must be the value of m_end_pos;
@@ -279,14 +278,14 @@ public:
                 if (++cur_pos == mp_res_nodes->end())
                 {
                     m_end_pos = true;
-                    return NULL;
+                    return nullptr;
                 }
                 m_cur_pos = cur_pos;
                 update_current_value();
                 return operator->();
             }
 
-            const ::std::pair<point, const data_type>* operator--()
+            const value_type* operator--()
             {
                 if (m_end_pos)
                 {
@@ -331,7 +330,7 @@ public:
                 m_cur_value.second = p->data;
             }
 
-            const ::std::pair<point, data_type>* get_current_value() const
+            const value_type* get_current_value() const
             {
                 return &m_cur_value;
             }
@@ -339,23 +338,23 @@ public:
         private:
             res_nodes_ptr mp_res_nodes;
             typename res_nodes_type::const_iterator m_cur_pos;
-            ::std::pair<point, data_type> m_cur_value;
+            value_type m_cur_value;
             bool m_end_pos:1;
         };
 
-        search_result() : mp_res_nodes(static_cast<res_nodes_type*>(NULL)) {}
-        search_result(const search_result& r) : mp_res_nodes(r.mp_res_nodes) {}
+        search_results() : mp_res_nodes(static_cast<res_nodes_type*>(nullptr)) {}
+        search_results(const search_results& r) : mp_res_nodes(r.mp_res_nodes) {}
 
-        typename search_result::const_iterator begin()
+        typename search_results::const_iterator begin()
         {
-            typename search_result::const_iterator itr(mp_res_nodes);
+            typename search_results::const_iterator itr(mp_res_nodes);
             itr.move_to_front();
             return itr;
         }
     
-        typename search_result::const_iterator end()
+        typename search_results::const_iterator end()
         {
-            typename search_result::const_iterator itr(mp_res_nodes);
+            typename search_results::const_iterator itr(mp_res_nodes);
             itr.move_to_end();
             return itr;
         }
@@ -384,7 +383,7 @@ public:
      * @param y y coordinate of new data position
      * @param data data being inserted at the specified coordinates.
      */
-    void insert(key_type x, key_type y, data_type data);
+    void insert(key_type x, key_type y, value_type data);
 
     /**
      * Perform region search (aka window search), that is, find all points 
@@ -413,7 +412,7 @@ public:
      * @return search result object containing all data found within the 
      *         specified region.
      */
-    search_result search_region(key_type x1, key_type y1, key_type x2, key_type y2) const;
+    search_results search_region(key_type x1, key_type y1, key_type x2, key_type y2) const;
 
     /**
      * Find data at specified coordinates.  If no data exists at the specified 
@@ -425,7 +424,7 @@ public:
      * 
      * @return data found at the specified coordinates.
      */
-    data_type find(key_type x, key_type y) const;
+    value_type find(key_type x, key_type y) const;
 
     /**
      * Remove data from specified coordinates.  This method does nothing if no 
@@ -475,7 +474,7 @@ public:
 
     bool operator!= (const point_quad_tree& r) const { return !operator== (r); }
 
-#ifdef UNIT_TEST
+#ifdef MDDS_UNIT_TEST
 public:
 #else
 private:
@@ -488,8 +487,8 @@ private:
     {
         key_type    x;
         key_type    y;
-        data_type  data;
-        node_data(key_type _x, key_type _y, data_type _data) :
+        value_type  data;
+        node_data(key_type _x, key_type _y, value_type _data) :
             x(_x), y(_y), data(_data) {}
         node_data(const node_data& r) : 
             x(r.x), y(r.y), data(r.data) {}
@@ -545,14 +544,14 @@ private:
     class search_result_inserter : public ::std::unary_function<const node*, void>
     {
     public:
-        search_result_inserter(search_result& result) : m_result(result) {}
+        search_result_inserter(search_results& result) : m_result(result) {}
 
         void operator() (const node* p)
         {
             m_result.push_back(p);
         }
     private:
-        search_result& m_result;
+        search_results& m_result;
     };
 
     class data_inserter : public ::std::unary_function<node_data, void>
@@ -574,7 +573,7 @@ private:
         key_type        dist;
         node_ptr        node;
 
-        node_distance() : quad(quad_unspecified), dist(0), node(NULL) {}
+        node_distance() : quad(quad_unspecified), dist(0), node(nullptr) {}
         node_distance(node_quadrant_t _quad, key_type _dist, const node_ptr& _node) : 
             quad(_quad), dist(_dist), node(_node) {}
     };
@@ -609,31 +608,31 @@ private:
     key_range_type m_yrange;
 };
 
-template<typename _Key, typename _Data>
-point_quad_tree<_Key,_Data>::point_quad_tree() :
-    m_root(NULL),
+template<typename _Key, typename _Value>
+point_quad_tree<_Key,_Value>::point_quad_tree() :
+    m_root(nullptr),
     m_xrange(0,0),
     m_yrange(0,0)
 {
 }
 
-template<typename _Key, typename _Data>
-point_quad_tree<_Key,_Data>::point_quad_tree(const point_quad_tree& r) :
-    m_root(NULL),
+template<typename _Key, typename _Value>
+point_quad_tree<_Key,_Value>::point_quad_tree(const point_quad_tree& r) :
+    m_root(nullptr),
     m_xrange(0,0),
     m_yrange(0,0)
 {
     insert_data_from(r);
 }
 
-template<typename _Key, typename _Data>
-point_quad_tree<_Key,_Data>::~point_quad_tree()
+template<typename _Key, typename _Value>
+point_quad_tree<_Key,_Value>::~point_quad_tree()
 {
     clear_all_nodes();
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::insert(key_type x, key_type y, data_type data)
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::insert(key_type x, key_type y, value_type data)
 {
     m_xrange.first  = ::std::min(m_xrange.first,  x);
     m_xrange.second = ::std::max(m_xrange.second, x);
@@ -707,8 +706,8 @@ void point_quad_tree<_Key,_Data>::insert(key_type x, key_type y, data_type data)
     assert(!"This should never be reached.");
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::search_region(key_type x1, key_type y1, key_type x2, key_type y2, data_array_type& result) const
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::search_region(key_type x1, key_type y1, key_type x2, key_type y2, data_array_type& result) const
 {
     using namespace std;
     const node* p = m_root.get();
@@ -716,21 +715,21 @@ void point_quad_tree<_Key,_Data>::search_region(key_type x1, key_type y1, key_ty
     ::mdds::search_region_node(p, x1, y1, x2, y2, _inserter);
 }
 
-template<typename _Key, typename _Data>
-typename point_quad_tree<_Key,_Data>::search_result
-point_quad_tree<_Key,_Data>::search_region(key_type x1, key_type y1, key_type x2, key_type y2) const
+template<typename _Key, typename _Value>
+typename point_quad_tree<_Key,_Value>::search_results
+point_quad_tree<_Key,_Value>::search_region(key_type x1, key_type y1, key_type x2, key_type y2) const
 {
     using namespace std;
-    search_result result;
+    search_results result;
     const node* p = m_root.get();
     search_result_inserter _inserter(result);
     ::mdds::search_region_node(p, x1, y1, x2, y2, _inserter);
     return result;
 }
 
-template<typename _Key, typename _Data>
-typename point_quad_tree<_Key,_Data>::data_type 
-point_quad_tree<_Key,_Data>::find(key_type x, key_type y) const
+template<typename _Key, typename _Value>
+typename point_quad_tree<_Key,_Value>::value_type
+point_quad_tree<_Key,_Value>::find(key_type x, key_type y) const
 {
     const node* p = find_node_ptr(x, y);
     if (!p)
@@ -738,8 +737,8 @@ point_quad_tree<_Key,_Data>::find(key_type x, key_type y) const
     return p->data;
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::remove(key_type x, key_type y)
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::remove(key_type x, key_type y)
 {
     using namespace std;
     node_ptr delete_node = find_node(x, y);
@@ -804,7 +803,6 @@ void point_quad_tree<_Key,_Data>::remove(key_type x, key_type y)
             adjust_quad(xrange, yrange, delete_node->southeast, dir_north, insert_list);
             set_new_root(xrange, yrange, delete_node->southwest, quad_northeast, insert_list);
             break;
-        case quad_unspecified:
         default:
             throw general_error("quadrant for the replacement node is unspecified.");
     }
@@ -837,7 +835,6 @@ void point_quad_tree<_Key,_Data>::remove(key_type x, key_type y)
             reinsert_tree(delete_node, quad_southwest, root);
         }
         break;
-        case quad_unspecified:
         default:
             throw general_error("quadrant for the replacement node is unspecified.");
     }
@@ -869,7 +866,6 @@ void point_quad_tree<_Key,_Data>::remove(key_type x, key_type y)
             delete_node->southwest = repl_node->southwest;
             repl_node->southwest.reset();
             break;
-        case quad_unspecified:
         default:
             throw general_error("quadrant for the replacement node is unspecified.");
     }
@@ -882,43 +878,43 @@ void point_quad_tree<_Key,_Data>::remove(key_type x, key_type y)
         reinsert_tree(delete_node, *itr);
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::swap(point_quad_tree& r)
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::swap(point_quad_tree& r)
 {
     m_root.swap(r.m_root);
     ::std::swap(m_xrange, r.m_xrange);
     ::std::swap(m_yrange, r.m_yrange);
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::clear()
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::clear()
 {
     clear_all_nodes();
 }
 
-template<typename _Key, typename _Data>
-bool point_quad_tree<_Key,_Data>::empty() const
+template<typename _Key, typename _Value>
+bool point_quad_tree<_Key,_Value>::empty() const
 {
-    return (m_root.get() == NULL);
+    return (m_root.get() == nullptr);
 }
 
-template<typename _Key, typename _Data>
-size_t point_quad_tree<_Key,_Data>::size() const
+template<typename _Key, typename _Value>
+size_t point_quad_tree<_Key,_Value>::size() const
 {
     size_t node_count = 0;
     count_all_nodes(m_root.get(), node_count);
     return node_count;
 }
 
-template<typename _Key, typename _Data>
-typename point_quad_tree<_Key,_Data>::node_access
-point_quad_tree<_Key,_Data>::get_node_access() const
+template<typename _Key, typename _Value>
+typename point_quad_tree<_Key,_Value>::node_access
+point_quad_tree<_Key,_Value>::get_node_access() const
 {
     return node_access(m_root.get());
 }
 
-template<typename _Key, typename _Data>
-point_quad_tree<_Key,_Data>& point_quad_tree<_Key,_Data>::operator= (const point_quad_tree& r)
+template<typename _Key, typename _Value>
+point_quad_tree<_Key,_Value>& point_quad_tree<_Key,_Value>::operator= (const point_quad_tree& r)
 {
     m_xrange = key_range_type(0, 0);
     m_yrange = key_range_type(0, 0);
@@ -927,8 +923,8 @@ point_quad_tree<_Key,_Data>& point_quad_tree<_Key,_Data>::operator= (const point
     return *this;
 }
 
-template<typename _Key, typename _Data>
-bool point_quad_tree<_Key,_Data>::operator== (const point_quad_tree& r) const
+template<typename _Key, typename _Value>
+bool point_quad_tree<_Key,_Value>::operator== (const point_quad_tree& r) const
 {
     ::std::vector<node_data> v1, v2;
     get_all_stored_data(v1);
@@ -936,8 +932,8 @@ bool point_quad_tree<_Key,_Data>::operator== (const point_quad_tree& r) const
     return equals(v1, v2);
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::dump_tree_svg(const ::std::string& fpath) const
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::dump_tree_svg(const ::std::string& fpath) const
 {
     using namespace std;
     ofstream file(fpath.c_str());
@@ -968,8 +964,8 @@ void draw_svg_arrow(::std::ofstream& file, const _NodePtr start, const _NodePtr
     file << "</g>" << endl;
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::dump_node_svg(const node* p, ::std::ofstream& file) const
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::dump_node_svg(const node* p, ::std::ofstream& file) const
 {
     using namespace std;
 
@@ -999,8 +995,8 @@ void point_quad_tree<_Key,_Data>::dump_node_svg(const node* p, ::std::ofstream&
     dump_node_svg(p->southwest.get(), file);
 }
 
-template<typename _Key, typename _Data>
-bool point_quad_tree<_Key,_Data>::equals(::std::vector<node_data>& v1, ::std::vector<node_data>& v2)
+template<typename _Key, typename _Value>
+bool point_quad_tree<_Key,_Value>::equals(::std::vector<node_data>& v1, ::std::vector<node_data>& v2)
 {
     using namespace std;
 
@@ -1027,8 +1023,8 @@ bool point_quad_tree<_Key,_Data>::equals(::std::vector<node_data>& v1, ::std::ve
     return true;
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::get_all_stored_data(::std::vector<node_data>& stored_data) const
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::get_all_stored_data(::std::vector<node_data>& stored_data) const
 {
     stored_data.clear();
     if (!m_root)
@@ -1037,8 +1033,8 @@ void point_quad_tree<_Key,_Data>::get_all_stored_data(::std::vector<node_data>&
     get_all_stored_data(m_root.get(), stored_data);
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::count_all_nodes(const node* p, size_t& node_count) const
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::count_all_nodes(const node* p, size_t& node_count) const
 {
     if (!p)
         return;
@@ -1051,8 +1047,8 @@ void point_quad_tree<_Key,_Data>::count_all_nodes(const node* p, size_t& node_co
     count_all_nodes(p->southwest.get(), node_count);
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::insert_data_from(const point_quad_tree& r)
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::insert_data_from(const point_quad_tree& r)
 {
     using namespace std;
     vector<node_data> all_data;
@@ -1060,25 +1056,25 @@ void point_quad_tree<_Key,_Data>::insert_data_from(const point_quad_tree& r)
     for_each(all_data.begin(), all_data.end(), data_inserter(*this));
 }
 
-template<typename _Key, typename _Data>
-bool point_quad_tree<_Key,_Data>::verify_data(::std::vector<node_data>& expected) const
+template<typename _Key, typename _Value>
+bool point_quad_tree<_Key,_Value>::verify_data(::std::vector<node_data>& expected) const
 {
     ::std::vector<node_data> stored;
     get_all_stored_data(stored);
     return equals(stored, expected);
 }
 
-template<typename _Key, typename _Data>
-bool point_quad_tree<_Key,_Data>::verify_node_iterator(const node_access& nac) const
+template<typename _Key, typename _Value>
+bool point_quad_tree<_Key,_Value>::verify_node_iterator(const node_access& nac) const
 {
     return verify_node_iterator(nac, m_root.get());
 }
 
-template<typename _Key, typename _Data>
-bool point_quad_tree<_Key,_Data>::verify_node_iterator(const node_access& nac, const node* p)
+template<typename _Key, typename _Value>
+bool point_quad_tree<_Key,_Value>::verify_node_iterator(const node_access& nac, const node* p)
 {
     if (!nac)
-        return (p == NULL);
+        return (p == nullptr);
 
     if (!p)
         return false;
@@ -1095,8 +1091,8 @@ bool point_quad_tree<_Key,_Data>::verify_node_iterator(const node_access& nac, c
     return true;
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::get_all_stored_data(const node* p, ::std::vector<node_data>& stored_data) const
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::get_all_stored_data(const node* p, ::std::vector<node_data>& stored_data) const
 {
     if (!p)
         return;
@@ -1109,9 +1105,9 @@ void point_quad_tree<_Key,_Data>::get_all_stored_data(const node* p, ::std::vect
     get_all_stored_data(p->southwest.get(), stored_data);
 }
 
-template<typename _Key, typename _Data>
-typename point_quad_tree<_Key,_Data>::node_ptr
-point_quad_tree<_Key,_Data>::find_node(key_type x, key_type y) const
+template<typename _Key, typename _Value>
+typename point_quad_tree<_Key,_Value>::node_ptr
+point_quad_tree<_Key,_Value>::find_node(key_type x, key_type y) const
 {
     node_ptr cur_node = m_root;
     while (cur_node)
@@ -1152,9 +1148,9 @@ point_quad_tree<_Key,_Data>::find_node(key_type x, key_type y) const
     return node_ptr();
 }
 
-template<typename _Key, typename _Data>
-const typename point_quad_tree<_Key,_Data>::node*
-point_quad_tree<_Key,_Data>::find_node_ptr(key_type x, key_type y) const
+template<typename _Key, typename _Value>
+const typename point_quad_tree<_Key,_Value>::node*
+point_quad_tree<_Key,_Value>::find_node_ptr(key_type x, key_type y) const
 {
     const node* cur_node = m_root.get();
     while (cur_node)
@@ -1170,34 +1166,34 @@ point_quad_tree<_Key,_Data>::find_node_ptr(key_type x, key_type y) const
         {
             case quad_northeast:
                 if (!cur_node->northeast)
-                    return NULL;
+                    return nullptr;
                 cur_node = cur_node->northeast.get();
                 break;
             case quad_northwest:
                 if (!cur_node->northwest)
-                    return NULL;
+                    return nullptr;
                 cur_node = cur_node->northwest.get();
                 break;
             case quad_southeast:
                 if (!cur_node->southeast)
-                    return NULL;
+                    return nullptr;
                 cur_node = cur_node->southeast.get();
                 break;
             case quad_southwest:
                 if (!cur_node->southwest)
-                    return NULL;
+                    return nullptr;
                 cur_node = cur_node->southwest.get();
                 break;
             default:
                 throw general_error("unknown quadrant");
         }
     }
-    return NULL;
+    return nullptr;
 }
 
-template<typename _Key, typename _Data>
-typename point_quad_tree<_Key,_Data>::node_ptr
-point_quad_tree<_Key,_Data>::find_replacement_node(key_type x, key_type y, const node_ptr& delete_node) const
+template<typename _Key, typename _Value>
+typename point_quad_tree<_Key,_Value>::node_ptr
+point_quad_tree<_Key,_Value>::find_replacement_node(key_type x, key_type y, const node_ptr& delete_node) const
 {
     using namespace std;
 
@@ -1265,8 +1261,8 @@ point_quad_tree<_Key,_Data>::find_replacement_node(key_type x, key_type y, const
     return node_ptr();
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::find_candidate_in_quad(
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::find_candidate_in_quad(
     key_type x, key_type y, 
     node_distance& dx_node, node_distance& dy_node, node_distance& min_city_block_node,
     const node_ptr& delete_node, node_quadrant_t quad) const
@@ -1307,8 +1303,8 @@ void point_quad_tree<_Key,_Data>::find_candidate_in_quad(
         min_city_block_node = node_distance(quad_unspecified, dx+dy, repl_node);
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::adjust_quad(
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::adjust_quad(
     const key_range_type& hatched_xrange, const key_range_type& hatched_yrange, 
     node_ptr quad_root, direction_t dir, reinsert_tree_array_type& insert_list)
 {
@@ -1357,8 +1353,8 @@ void point_quad_tree<_Key,_Data>::adjust_quad(
     }
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::set_new_root(
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::set_new_root(
     const key_range_type& hatched_xrange, const key_range_type& hatched_yrange, 
     node_ptr& quad_root, node_quadrant_t dir, reinsert_tree_array_type& insert_list)
 {
@@ -1390,13 +1386,13 @@ void point_quad_tree<_Key,_Data>::set_new_root(
     }
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::insert_node(node_ptr& dest, node_ptr& node)
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::insert_node(node_ptr& dest, node_ptr& this_node)
 {
     node_ptr cur_node = dest;
     while (true)
     {
-        if (cur_node->x == node->x && cur_node->y == node->y)
+        if (cur_node->x == this_node->x && cur_node->y == this_node->y)
         {
             // When inserting a node instance directly (likely as part of tree
             // re-insertion), we are not supposed to have another node at
@@ -1404,7 +1400,7 @@ void point_quad_tree<_Key,_Data>::insert_node(node_ptr& dest, node_ptr& node)
             throw general_error("node with identical position encountered.");
         }
 
-        node_quadrant_t quad = cur_node->get_quadrant(node->x, node->y);
+        node_quadrant_t quad = cur_node->get_quadrant(this_node->x, this_node->y);
         switch (quad)
         {
             case quad_northeast:
@@ -1412,8 +1408,8 @@ void point_quad_tree<_Key,_Data>::insert_node(node_ptr& dest, node_ptr& node)
                     cur_node = cur_node->northeast;
                 else
                 {
-                    cur_node->northeast = node;
-                    node->parent = cur_node;
+                    cur_node->northeast = this_node;
+                    this_node->parent = cur_node;
                     return;
                 }
                 break;
@@ -1422,8 +1418,8 @@ void point_quad_tree<_Key,_Data>::insert_node(node_ptr& dest, node_ptr& node)
                     cur_node = cur_node->northwest;
                 else
                 {
-                    cur_node->northwest = node;
-                    node->parent = cur_node;
+                    cur_node->northwest = this_node;
+                    this_node->parent = cur_node;
                     return;
                 }
                 break;
@@ -1432,8 +1428,8 @@ void point_quad_tree<_Key,_Data>::insert_node(node_ptr& dest, node_ptr& node)
                     cur_node = cur_node->southeast;
                 else
                 {
-                    cur_node->southeast = node;
-                    node->parent = cur_node;
+                    cur_node->southeast = this_node;
+                    this_node->parent = cur_node;
                     return;
                 }
                 break;
@@ -1442,8 +1438,8 @@ void point_quad_tree<_Key,_Data>::insert_node(node_ptr& dest, node_ptr& node)
                     cur_node = cur_node->southwest;
                 else
                 {
-                    cur_node->southwest = node;
-                    node->parent = cur_node;
+                    cur_node->southwest = this_node;
+                    this_node->parent = cur_node;
                     return;
                 }
                 break;
@@ -1454,8 +1450,8 @@ void point_quad_tree<_Key,_Data>::insert_node(node_ptr& dest, node_ptr& node)
     assert(!"This should never be reached.");
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::reinsert_tree(node_ptr& dest, node_ptr& root)
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::reinsert_tree(node_ptr& dest, node_ptr& root)
 {
     assert(dest); // Destination node should not be null.
 
@@ -1488,8 +1484,8 @@ void point_quad_tree<_Key,_Data>::reinsert_tree(node_ptr& dest, node_ptr& root)
     insert_node(dest, root);
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::reinsert_tree(node_ptr& dest, node_quadrant_t quad, node_ptr& root)
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::reinsert_tree(node_ptr& dest, node_quadrant_t quad, node_ptr& root)
 {
     if (!root)
         // Nothing to re-insert.  Bail out.
@@ -1533,14 +1529,13 @@ void point_quad_tree<_Key,_Data>::reinsert_tree(node_ptr& dest, node_quadrant_t
                 root->parent = dest;
             }
             break;
-        case quad_unspecified:
         default:
             throw general_error("reinsert_tree: quadrant unspecified");
     }
 }
 
-template<typename _Key, typename _Data>
-void point_quad_tree<_Key,_Data>::clear_all_nodes()
+template<typename _Key, typename _Value>
+void point_quad_tree<_Key,_Value>::clear_all_nodes()
 {
     ::mdds::disconnect_all_nodes(m_root);
     m_root.reset();
