@@ -1,6 +1,6 @@
 /*************************************************************************
  *
- * Copyright (c) 2008-2012 Kohei Yoshida
+ * Copyright (c) 2008-2018 Kohei Yoshida
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
@@ -28,13 +28,13 @@
 #include "mdds/flat_segment_tree.hpp"
 #include "test_global.hpp"
 
-#include <list>
 #include <iostream>
 #include <string>
 #include <vector>
 #include <limits>
 #include <iterator>
 #include <algorithm>
+#include <memory>
 
 #define ARRAY_SIZE(x) sizeof(x)/sizeof(x[0])
 
@@ -143,14 +143,14 @@ void fst_test_tree_build()
         int lower = 0, upper = 100, delta = 10;
         flat_segment_tree<int, int> db(lower, upper, 0);
         {
-            stack_printer __stack_printer__("::fst_test_tree_build insertion");
+            stack_printer __stack_printer2__("::fst_test_tree_build insertion");
             for (int i = lower; i < upper; i+=delta)
                 db.insert_front(i, i+delta, i*2);
         }
         db.dump_leaf_nodes();
 
         {
-            stack_printer __stack_printer__("::fst_test_tree_build tree construction");
+            stack_printer __stack_printer2__("::fst_test_tree_build tree construction");
             db.build_tree();
             db.dump_tree();
         }
@@ -1642,8 +1642,8 @@ void fst_perf_test_position_search()
         stack_printer __stack_printer__("::fst_perf_test_position_search (normal)");
         for (long i = 0; i < upper; ++i)
         {
-            bool val;
-            ret_type ret = db.search(i, val);
+            bool val2;
+            ret_type ret = db.search(i, val2);
             assert(ret.second);
         }
     }
@@ -1653,8 +1653,8 @@ void fst_perf_test_position_search()
         itr = db.begin();
         for (long i = 0; i < upper; ++i)
         {
-            bool val;
-            ret_type ret = db.search(itr, i, val);
+            bool val2;
+            ret_type ret = db.search(itr, i, val2);
             assert(ret.second);
             itr = ret.first;
         }
@@ -1814,6 +1814,29 @@ void fst_test_swap()
     assert(val == 2);
 }
 
+void fst_test_swap_tree_memory()
+{
+    stack_printer __stack_printer__("::fst_test_swap_tree_memory");
+    typedef flat_segment_tree<long, int> db_type;
+    auto db1 = mdds::make_unique<db_type>(0, 100, 0);
+    db1->insert_back(10, 40, 999);
+    db1->build_tree();
+    int value = -1;
+    db1->search_tree(20, value);
+    assert(value == 999);
+
+    db_type db2(-10, 10, -99);
+    db2.swap(*db1);
+
+    db1.reset();
+
+    // Make sure that the tree is valid, and you can still search through the tree.
+    assert(db2.is_tree_valid());
+    value = -1;
+    db2.search_tree(20, value);
+    assert(value == 999);
+}
+
 void fst_test_clear()
 {
     stack_printer __stack_printer__("::fst_test_clear");
@@ -1987,6 +2010,22 @@ void fst_test_insert_out_of_bound()
     pos = ret.first;
 }
 
+void fst_test_insert_out_of_bound_2()
+{
+    stack_printer __stack_printer__("::fst_test_insert_out_of_bound_2");
+
+    typedef flat_segment_tree<int, bool> db_type;
+    db_type db(0, 256, false);
+
+    // The range is entirely out-of-bound, but the start range equals the
+    // upper bound of the valid range.
+    auto ret = db.insert_back(256, 1024, true);
+
+    // Insertion never took place.
+    assert(ret.first == db.end());
+    assert(!ret.second);
+}
+
 void fst_test_segment_iterator()
 {
     stack_printer __stack_printer__("::fst_test_segment_iterator");
@@ -2112,10 +2151,12 @@ int main (int argc, char **argv)
             fst_test_position_search();
             fst_test_min_max_default();
             fst_test_swap();
+            fst_test_swap_tree_memory();
             fst_test_clear();
             fst_test_assignment();
             fst_test_non_numeric_value();
             fst_test_insert_out_of_bound();
+            fst_test_insert_out_of_bound_2();
             fst_test_segment_iterator();
         }
 
